==> sgq-web-1.1.1-sources.jar: com/herbocailleau/sgq/web/actions/user/BatchEditAction.java <==
/*
 * #%L
 * SGQ :: Web
 * $Id: BatchEditAction.java 279 2013-03-20 15:08:54Z echatellier $
 * $HeadURL: http://svn.forge.codelutin.com/svn/sgq-ch/tags/sgq-ch-1.1.1/sgq-web/src/main/java/com/herbocailleau/sgq/web/actions/user/BatchEditAction.java $
 * %%
 * Copyright (C) 2012 Herboristerie Cailleau
 * %%
 * Herboristerie Cailleau - Tous droits réservés
 * #L%
 */

package com.herbocailleau.sgq.web.actions.user;

import java.text.ParseException;

import org.apache.commons.lang3.StringUtils;
import org.apache.struts2.convention.annotation.Action;
import org.apache.struts2.convention.annotation.Result;

import com.herbocailleau.sgq.business.SgqUtils;
import com.herbocailleau.sgq.business.services.BatchService;
import com.herbocailleau.sgq.entities.Batch;
import com.herbocailleau.sgq.web.SgqActionSupport;

/**
 * Action d'edition des informations d'un lot (dpmes, date d'expiration).
 * 
 * @author echatellier
 */
public class BatchEditAction extends SgqActionSupport {

    /** serialVersionUID. */
    private static final long serialVersionUID = 3074255662512738956L;

    protected String batchId;

    protected Batch batch;

    protected String dpmes;
    
    protected String comment;
    
    protected String expiredDate;

    public void setBatchId(String batchId) {
        this.batchId = batchId;
    }

    @Override
    public String input() throws Exception {
        BatchService batchService = newService(BatchService.class);
        batch = batchService.getBatchById(batchId);
        return INPUT;
    }

    public Batch getBatch() {
        return batch;
    }

    public void setDpmes(String dpmes) {
        this.dpmes = dpmes;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

    public void setExpiredDate(String expiredDate) {
        this.expiredDate = expiredDate;
    }

    @Override
    @Action(results={@Result(type="redirectAction", params = {"actionName", "batch-view", "batchId", "${batch.topiaId}"})})
    public String execute() throws Exception {
        String result = SUCCESS;

        BatchService batchService = newService(BatchService.class);
        batch = batchService.getBatchById(batchId);

        try {
            if (dpmes != null) { // security : not displayed in form
                if (StringUtils.isNotBlank(dpmes)) {
                    batch.setDpmes(SgqUtils.parseSgqDate(dpmes));
                } else {
                    batch.setDpmes(null);
                }
            }
            if (expiredDate != null) { // security : not displayed in form
                if (StringUtils.isNotBlank(expiredDate)) {
                    batch.setExpiredDate(SgqUtils.parseSgqDate(expiredDate));
                } else {
                    batch.setExpiredDate(null);
                }
            }
            if (comment != null) { // security : not displayed in form
                batch.setComment(comment);
            }
            
            batchService.saveBatch(batch);
        } catch (ParseException ex) {
            addActionError("Format de date invalide (dd/MM/yyyy)");
            result = INPUT;
        }
        return result;
    }
}

==> sgq-web-1.1.2-sources.jar: com/herbocailleau/sgq/web/actions/user/BatchEditAction.java <==
/*
 * #%L
 * SGQ :: Web
 * $Id: BatchEditAction.java 421 2013-07-24 08:53:41Z echatellier $
 * $HeadURL: http://svn.forge.codelutin.com/svn/sgq-ch/tags/sgq-ch-1.1.2/sgq-web/src/main/java/com/herbocailleau/sgq/web/actions/user/BatchEditAction.java $
 * %%
 * Copyright (C) 2012 Herboristerie Cailleau
 * %%
 * Herboristerie Cailleau - Tous droits réservés
 * #L%
 */

package com.herbocailleau.sgq.web.actions.user;

import java.text.ParseException;

import org.apache.commons.lang3.StringUtils;
import org.apache.struts2.convention.annotation.Action;
import org.apache.struts2.convention.annotation.Result;

import com.herbocailleau.sgq.business.SgqUtils;
import com.herbocailleau.sgq.business.services.BatchService;
import com.herbocailleau.sgq.entities.Batch;
import com.herbocailleau.sgq.web.SgqActionSupport;

/**
 * Action d'edition des informations d'un lot (dpmes, date d'expiration).
 * 
 * @author echatellier
 */
public class BatchEditAction extends SgqActionSupport {

    /** serialVersionUID. */
    private static final long serialVersionUID = 3074255662512738956L;

    protected String batchId;

    protected Batch batch;

    protected String dpmes;
    
    protected String comment;
    
    protected String expiredDate;

    public void setBatchId(String batchId) {
        this.batchId = batchId;
    }

    @Override
    public String input() throws Exception {
        loadData();
        return INPUT;
    }
    
    protected void loadData() {
        BatchService batchService = newService(BatchService.class);
        batch = batchService.getBatchById(batchId);
    }

    public Batch getBatch() {
        return batch;
    }

    public void setDpmes(String dpmes) {
        this.dpmes = dpmes;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

    public void setExpiredDate(String expiredDate) {
        this.expiredDate = expiredDate;
    }

    @Override
    public void validate() {
        if (dpmes != null) { // security : not displayed in form
            if (StringUtils.isNotBlank(dpmes) && !dpmes.matches("\\d{1,2}/\\d{1,2}/\\d{4}")) {
                addActionError("Le format de la dmesd est incorrect : jj/mm/aaaa");
            }
        }
        if (expiredDate != null) { // security : not displayed in form
            if (StringUtils.isNotBlank(expiredDate) && !expiredDate.matches("\\d{1,2}/\\d{1,2}/\\d{4}")) {
                addActionError("Le format de la date d'expiration est incorrect : jj/mm/aaaa");
            }
        }
        
        if (hasErrors()) {
            loadData();
        }
    }

    @Override
    @Action(results={@Result(type="redirectAction", params = {"actionName", "batch-view", "batchId", "${batch.topiaId}"})})
    public String execute() throws Exception {
        String result = SUCCESS;

        BatchService batchService = newService(BatchService.class);
        batch = batchService.getBatchById(batchId);

        try {
            if (dpmes != null) { // security : not displayed in form
                if (StringUtils.isNotBlank(dpmes)) {
                    batch.setDpmes(SgqUtils.parseSgqDate(dpmes));
                } else {
                    batch.setDpmes(null);
                }
            }
            if (expiredDate != null) { // security : not displayed in form
                if (StringUtils.isNotBlank(expiredDate)) {
                    batch.setExpiredDate(SgqUtils.parseSgqDate(expiredDate));
                } else {
                    batch.setExpiredDate(null);
                }
            }
            if (comment != null) { // security : not displayed in form
                batch.setComment(comment);
            }
            
            batchService.saveBatch(batch);
        } catch (ParseException ex) {
            addActionError("Format de date invalide (dd/MM/yyyy)");
            result = INPUT;
        }
        return result;
    }
}
